CVS commit: [netbsd-6] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 13:44:55 UTC 2015

Modified Files:
src/doc [netbsd-6]: CHANGES-6.2

Log Message:
Ticket #1239


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.188 -r1.1.2.189 src/doc/CHANGES-6.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.2
diff -u src/doc/CHANGES-6.2:1.1.2.188 src/doc/CHANGES-6.2:1.1.2.189
--- src/doc/CHANGES-6.2:1.1.2.188	Sun Jan 25 10:25:54 2015
+++ src/doc/CHANGES-6.2	Mon Jan 26 13:44:55 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.2,v 1.1.2.188 2015/01/25 10:25:54 martin Exp $
+# $NetBSD: CHANGES-6.2,v 1.1.2.189 2015/01/26 13:44:55 martin Exp $
 
 A complete list of changes from the 6.1 release until the 6.2 release:
 
@@ -9493,3 +9493,14 @@ libexec/ld.elf_so/rtld.c			1.160-1.161
 	want to do an unpark.
 	[he, ticket #1238]
 
+sys/arch/x86/pci/ichlpcib.c			1.46
+
+	The PMBASE and GPIOBASE registers are not compltible with
+	the PCI spec and the map sizes are fixed to 128bytes. The
+	pci_mapreg_submap() function has a code to check the range
+	of the BAR. The PCI_MAPREG_IO_SIZE() macro returns lower
+	than 128bytes on some machines. This makes it impossible to
+	use pci_mapreg_submap(). Use pci_conf_read() and
+	bus_space_map() directly.
+	[msaitoh, ticket #1239]
+



CVS commit: [netbsd-5] src/sys/arch/x86/pci

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 13:34:03 UTC 2015

Modified Files:
src/sys/arch/x86/pci [netbsd-5]: ichlpcib.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #1944):
sys/arch/x86/pci/ichlpcib.c: revision 1.46

The PMBASE and GPIOBASE registers are not compltible with the PCI spec
and the map sizes are fixed to 128bytes. The pci_mapreg_submap()
function has a code to check the range of the BAR. The
PCI_MAPREG_IO_SIZE() macro returns lower than 128bytes on some
machines. It makes impossible to use pci_mapreg_submap(). Use
pci_conf_read() and bus_space_map() directly.


To generate a diff of this commit:
cvs rdiff -u -r1.14.4.3 -r1.14.4.4 src/sys/arch/x86/pci/ichlpcib.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x86/pci/ichlpcib.c
diff -u src/sys/arch/x86/pci/ichlpcib.c:1.14.4.3 src/sys/arch/x86/pci/ichlpcib.c:1.14.4.4
--- src/sys/arch/x86/pci/ichlpcib.c:1.14.4.3	Fri Jan 23 16:24:55 2015
+++ src/sys/arch/x86/pci/ichlpcib.c	Mon Jan 26 13:34:03 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ichlpcib.c,v 1.14.4.3 2015/01/23 16:24:55 martin Exp $	*/
+/*	$NetBSD: ichlpcib.c,v 1.14.4.4 2015/01/26 13:34:03 martin Exp $	*/
 
 /*-
  * Copyright (c) 2004 The NetBSD Foundation, Inc.
@@ -39,7 +39,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ichlpcib.c,v 1.14.4.3 2015/01/23 16:24:55 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: ichlpcib.c,v 1.14.4.4 2015/01/26 13:34:03 martin Exp $);
 
 #include sys/types.h
 #include sys/param.h
@@ -184,6 +184,7 @@ lpcibattach(device_t parent, device_t se
 	struct pci_attach_args *pa = aux;
 	struct lpcib_softc *sc = device_private(self);
 	struct lpcib_device *lpcib_dev;
+	pcireg_t pmbase;
 
 	sc-sc_pa = *pa;
 
@@ -205,11 +206,16 @@ lpcibattach(device_t parent, device_t se
 	 *
 	 * The PMBASE register is alike PCI BAR but not completely compatible
 	 * with it. The PMBASE define the base address and the type but
-	 * not describe the size.
+	 * not describe the size. The value of the register may be lower
+	 * than LPCIB_PCI_PM_SIZE. It makes impossible to use
+	 * pci_mapreg_submap() because the function does range check.
 	 */
-	if (pci_mapreg_submap(pa, LPCIB_PCI_PMBASE, PCI_MAPREG_TYPE_IO, 0,
-		LPCIB_PCI_PM_SIZE, 0, sc-sc_iot, sc-sc_ioh, NULL, NULL)) {
-		aprint_error_dev(self, can't map power management i/o space\n);
+	sc-sc_iot = pa-pa_iot;
+	pmbase = pci_conf_read(pa-pa_pc, pa-pa_tag, LPCIB_PCI_PMBASE);
+	if (bus_space_map(sc-sc_iot, PCI_MAPREG_IO_ADDR(pmbase),
+	LPCIB_PCI_PM_SIZE, 0, sc-sc_ioh) != 0) {
+		aprint_error_dev(self,
+		can't map power management i/o space\n);
 		return;
 	}
 



CVS commit: [netbsd-6] src/sys/arch/x86/pci

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 13:43:44 UTC 2015

Modified Files:
src/sys/arch/x86/pci [netbsd-6]: ichlpcib.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #1239):
sys/arch/x86/pci/ichlpcib.c: revision 1.46
The PMBASE and GPIOBASE registers are not
compatible with the PCI spec and the map sizes are fixed to 128bytes. The
pci_mapreg_submap() function has a code to check the range of the BAR. The
PCI_MAPREG_IO_SIZE() macro returns lower than 128bytes on some machines.
This makes it impossible to use pci_mapreg_submap(). Use pci_conf_read() and
bus_space_map() directly.


To generate a diff of this commit:
cvs rdiff -u -r1.34.6.1 -r1.34.6.2 src/sys/arch/x86/pci/ichlpcib.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x86/pci/ichlpcib.c
diff -u src/sys/arch/x86/pci/ichlpcib.c:1.34.6.1 src/sys/arch/x86/pci/ichlpcib.c:1.34.6.2
--- src/sys/arch/x86/pci/ichlpcib.c:1.34.6.1	Fri Jan 16 08:22:25 2015
+++ src/sys/arch/x86/pci/ichlpcib.c	Mon Jan 26 13:43:44 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ichlpcib.c,v 1.34.6.1 2015/01/16 08:22:25 snj Exp $	*/
+/*	$NetBSD: ichlpcib.c,v 1.34.6.2 2015/01/26 13:43:44 martin Exp $	*/
 
 /*-
  * Copyright (c) 2004 The NetBSD Foundation, Inc.
@@ -39,7 +39,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ichlpcib.c,v 1.34.6.1 2015/01/16 08:22:25 snj Exp $);
+__KERNEL_RCSID(0, $NetBSD: ichlpcib.c,v 1.34.6.2 2015/01/26 13:43:44 martin Exp $);
 
 #include sys/types.h
 #include sys/param.h
@@ -260,6 +260,7 @@ lpcibattach(device_t parent, device_t se
 	struct pci_attach_args *pa = aux;
 	struct lpcib_softc *sc = device_private(self);
 	struct lpcib_device *lpcib_dev;
+	pcireg_t pmbase;
 
 	sc-sc_pa = *pa;
 
@@ -281,12 +282,16 @@ lpcibattach(device_t parent, device_t se
 	 *
 	 * The PMBASE register is alike PCI BAR but not completely compatible
 	 * with it. The PMBASE define the base address and the type but
-	 * not describe the size.
+	 * not describe the size. The value of the register may be lower
+	 * than LPCIB_PCI_PM_SIZE. It makes impossible to use
+	 * pci_mapreg_submap() because the function does range check.
 	 */
-	if (pci_mapreg_submap(pa, LPCIB_PCI_PMBASE, PCI_MAPREG_TYPE_IO, 0,
-		LPCIB_PCI_PM_SIZE, 0, sc-sc_iot, sc-sc_ioh, NULL,
-		sc-sc_iosize)) {
-		aprint_error_dev(self, can't map power management i/o space\n);
+	sc-sc_iot = pa-pa_iot;
+	pmbase = pci_conf_read(pa-pa_pc, pa-pa_tag, LPCIB_PCI_PMBASE);
+	if (bus_space_map(sc-sc_iot, PCI_MAPREG_IO_ADDR(pmbase),
+	LPCIB_PCI_PM_SIZE, 0, sc-sc_ioh) != 0) {
+		aprint_error_dev(self,
+		can't map power management i/o space\n);
 		return;
 	}
 
@@ -1039,11 +1044,14 @@ lpcib_gpio_configure(device_t self)
 	/*
 	 * The GPIO_BASE register is alike PCI BAR but not completely
 	 * compatible with it. The PMBASE define the base address and the type
-	 * but not describe the size.
+	 * but not describe the size. The value of the register may be lower
+	 * than LPCIB_PCI_GPIO_SIZE. It makes impossible to use
+	 * pci_mapreg_submap() because the function does range check.
 	 */
-	rv = pci_mapreg_submap(sc-sc_pa, base_reg, PCI_MAPREG_TYPE_IO, 0,
-	LPCIB_PCI_GPIO_SIZE, 0, sc-sc_gpio_iot, sc-sc_gpio_ioh,
-	NULL, sc-sc_gpio_ios);
+	sc-sc_gpio_iot = sc-sc_pa.pa_iot;
+	reg = pci_conf_read(sc-sc_pa.pa_pc, sc-sc_pa.pa_tag, base_reg);
+	rv = bus_space_map(sc-sc_gpio_iot, PCI_MAPREG_IO_ADDR(reg),
+	LPCIB_PCI_GPIO_SIZE, 0, sc-sc_gpio_ioh);
 	if (rv != 0) {
 		aprint_error_dev(self, can't map general purpose i/o space(rv = %d)\n, rv);
 		return;



CVS commit: [netbsd-6] src/sys/arch/x86/include

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 13:58:05 UTC 2015

Modified Files:
src/sys/arch/x86/include [netbsd-6]: specialreg.h

Log Message:
Pull up the following, requested by msaitoh in ticket #1240:

sys/arch/x86/include/specialreg.h   1.72 via patch

Add CPUID_TO_*() macros to avoid bug. Old macros are kept for compatibility.
See http://mail-index.netbsd.org/port-amd64/2013/11/12/msg001978.html


To generate a diff of this commit:
cvs rdiff -u -r1.55.2.4 -r1.55.2.5 src/sys/arch/x86/include/specialreg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-6.2
diff -u src/doc/CHANGES-6.2:1.1.2.189 src/doc/CHANGES-6.2:1.1.2.190
--- src/doc/CHANGES-6.2:1.1.2.189	Mon Jan 26 13:44:55 2015
+++ src/doc/CHANGES-6.2	Mon Jan 26 14:04:22 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-6.2,v 1.1.2.189 2015/01/26 13:44:55 martin Exp $
+# $NetBSD: CHANGES-6.2,v 1.1.2.190 2015/01/26 14:04:22 martin Exp $
 
 A complete list of changes from the 6.1 release until the 6.2 release:
 
@@ -9504,3 +9504,20 @@ sys/arch/x86/pci/ichlpcib.c			1.46
 	bus_space_map() directly.
 	[msaitoh, ticket #1239]
 
+sys/arch/x86/include/specialreg.h			1.72 via patch
+
+	Add CPUID_TO_*() macros to avoid bug. Old macros are kept for
+	compatibility.
+	See http://mail-index.netbsd.org/port-amd64/2013/11/12/msg001978.html
+	[msaitoh, ticket #1240]
+
+sys/arch/x86/x86/identcpu.c			1.35-1.39
+
+	- Check cpuid leaf 4 for newer Intel CPU to know the cache information.
+	  This code might improve performance because it changes the number of
+	  page colors.
+	- Fix calculation of the cpu model (display model) in
+	  cpu_probe_amd_cache().
+	- CPUID leaf 2 and 4 are only for Intel processors.
+	[msaitoh, ticket #1241]
+



CVS commit: [netbsd-7] src/external/mit/xorg/lib/freetype

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 16:20:48 UTC 2015

Modified Files:
src/external/mit/xorg/lib/freetype [netbsd-7]: Makefile

Log Message:
Pull up following revision(s) (requested by wiz in ticket #457):
external/mit/xorg/lib/freetype/Makefile: revision 1.13
Fix PKG_CONFIG version after freetype2-2.5.3 import.
From Leonardo Taccari on tech-x11.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.12.4.1 src/external/mit/xorg/lib/freetype/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/mit/xorg/lib/freetype/Makefile
diff -u src/external/mit/xorg/lib/freetype/Makefile:1.12 src/external/mit/xorg/lib/freetype/Makefile:1.12.4.1
--- src/external/mit/xorg/lib/freetype/Makefile:1.12	Thu Mar 20 08:57:48 2014
+++ src/external/mit/xorg/lib/freetype/Makefile	Mon Jan 26 16:20:48 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.12 2014/03/20 08:57:48 mrg Exp $
+#	$NetBSD: Makefile,v 1.12.4.1 2015/01/26 16:20:48 martin Exp $
 
 .include bsd.own.mk
 
@@ -100,7 +100,7 @@ LIBDPLIBS= \
 
 PKGCONFIG=	freetype2
 PKGDIST.freetype2=	${.CURDIR}
-PKGCONFIG_VERSION.freetype2=	9.20.3
+PKGCONFIG_VERSION.freetype2=	17.2.11
 
 .include bsd.x11.mk
 .include bsd.lib.mk



CVS commit: [netbsd-7] src/external/gpl3/gcc/dist/libsanitizer/tsan

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 16:23:03 UTC 2015

Modified Files:
src/external/gpl3/gcc/dist/libsanitizer/tsan [netbsd-7]:
tsan_rtl_amd64.S

Log Message:
Pull up following revision(s) (requested by skrll in ticket #458):
external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S: revision 1.2
fix for PIC code.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.1 -r1.1.1.1.6.1 \
src/external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S
diff -u src/external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S:1.1.1.1 src/external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S:1.1.1.1.6.1
--- src/external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S:1.1.1.1	Sat Mar  1 08:41:18 2014
+++ src/external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S	Mon Jan 26 16:23:03 2015
@@ -40,7 +40,11 @@ __tsan_trace_switch_thunk:
   shr $4, %rsp  # clear 4 lsb, align to 16
   shl $4, %rsp
 
+#ifdef __PIC__
+  call __tsan_trace_switch@PLT
+#else
   call __tsan_trace_switch
+#endif
 
   # Unalign stack frame back.
   mov %rbx, %rsp  # restore the original rsp
@@ -119,7 +123,11 @@ __tsan_report_race_thunk:
   shr $4, %rsp  # clear 4 lsb, align to 16
   shl $4, %rsp
 
+#ifdef __PIC__
+  call __tsan_report_race@PLT
+#else
   call __tsan_report_race
+#endif
 
   # Unalign stack frame back.
   mov %rbx, %rsp  # restore the original rsp



CVS commit: [netbsd-7] src/sys/arch/x86/pci

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 16:16:11 UTC 2015

Modified Files:
src/sys/arch/x86/pci [netbsd-7]: ichlpcib.c

Log Message:
Pull up following revision(s) (requested by msaitoh in ticket #455):
sys/arch/x86/pci/ichlpcib.c: revision 1.46

The PMBASE and GPIOBASE registers are not compatible with the PCI spec
and the map sizes are fixed to 128bytes. The pci_mapreg_submap()
function has a code to check the range of the BAR. The
PCI_MAPREG_IO_SIZE() macro returns lower than 128bytes on some
machines. This makes it impossible to use pci_mapreg_submap(). Use
pci_conf_read() and bus_space_map() directly.


To generate a diff of this commit:
cvs rdiff -u -r1.43.4.1 -r1.43.4.2 src/sys/arch/x86/pci/ichlpcib.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x86/pci/ichlpcib.c
diff -u src/sys/arch/x86/pci/ichlpcib.c:1.43.4.1 src/sys/arch/x86/pci/ichlpcib.c:1.43.4.2
--- src/sys/arch/x86/pci/ichlpcib.c:1.43.4.1	Thu Jan  8 11:39:38 2015
+++ src/sys/arch/x86/pci/ichlpcib.c	Mon Jan 26 16:16:11 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ichlpcib.c,v 1.43.4.1 2015/01/08 11:39:38 martin Exp $	*/
+/*	$NetBSD: ichlpcib.c,v 1.43.4.2 2015/01/26 16:16:11 martin Exp $	*/
 
 /*-
  * Copyright (c) 2004 The NetBSD Foundation, Inc.
@@ -39,7 +39,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ichlpcib.c,v 1.43.4.1 2015/01/08 11:39:38 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: ichlpcib.c,v 1.43.4.2 2015/01/26 16:16:11 martin Exp $);
 
 #include sys/types.h
 #include sys/param.h
@@ -301,6 +301,7 @@ lpcibattach(device_t parent, device_t se
 	struct pci_attach_args *pa = aux;
 	struct lpcib_softc *sc = device_private(self);
 	struct lpcib_device *lpcib_dev;
+	pcireg_t pmbase;
 
 	sc-sc_pa = *pa;
 
@@ -322,12 +323,16 @@ lpcibattach(device_t parent, device_t se
 	 *
 	 * The PMBASE register is alike PCI BAR but not completely compatible
 	 * with it. The PMBASE define the base address and the type but
-	 * not describe the size.
+	 * not describe the size. The value of the register may be lower
+	 * than LPCIB_PCI_PM_SIZE. It makes impossible to use
+	 * pci_mapreg_submap() because the function does range check.
 	 */
-	if (pci_mapreg_submap(pa, LPCIB_PCI_PMBASE, PCI_MAPREG_TYPE_IO, 0,
-		LPCIB_PCI_PM_SIZE, 0, sc-sc_iot, sc-sc_ioh, NULL,
-		sc-sc_iosize)) {
-		aprint_error_dev(self, can't map power management i/o space\n);
+	sc-sc_iot = pa-pa_iot;
+	pmbase = pci_conf_read(pa-pa_pc, pa-pa_tag, LPCIB_PCI_PMBASE);
+	if (bus_space_map(sc-sc_iot, PCI_MAPREG_IO_ADDR(pmbase),
+	LPCIB_PCI_PM_SIZE, 0, sc-sc_ioh) != 0) {
+		aprint_error_dev(self,
+		can't map power management i/o space\n);
 		return;
 	}
 
@@ -1080,11 +1085,14 @@ lpcib_gpio_configure(device_t self)
 	/*
 	 * The GPIO_BASE register is alike PCI BAR but not completely
 	 * compatible with it. The PMBASE define the base address and the type
-	 * but not describe the size.
+	 * but not describe the size. The value of the register may be lower
+	 * than LPCIB_PCI_GPIO_SIZE. It makes impossible to use
+	 * pci_mapreg_submap() because the function does range check.
 	 */
-	rv = pci_mapreg_submap(sc-sc_pa, base_reg, PCI_MAPREG_TYPE_IO, 0,
-	LPCIB_PCI_GPIO_SIZE, 0, sc-sc_gpio_iot, sc-sc_gpio_ioh,
-	NULL, sc-sc_gpio_ios);
+	sc-sc_gpio_iot = sc-sc_pa.pa_iot;
+	reg = pci_conf_read(sc-sc_pa.pa_pc, sc-sc_pa.pa_tag, base_reg);
+	rv = bus_space_map(sc-sc_gpio_iot, PCI_MAPREG_IO_ADDR(reg),
+	LPCIB_PCI_GPIO_SIZE, 0, sc-sc_gpio_ioh);
 	if (rv != 0) {
 		aprint_error_dev(self, can't map general purpose i/o space(rv = %d)\n, rv);
 		return;



CVS commit: [netbsd-7] src/sys/arch/powerpc/booke

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 16:18:42 UTC 2015

Modified Files:
src/sys/arch/powerpc/booke [netbsd-7]: e500_timer.c

Log Message:
Pull up following revision(s) (requested by nonaka in ticket #456):
sys/arch/powerpc/booke/e500_timer.c: revision 1.6
fix build failure with lockstat.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.5.2.1 src/sys/arch/powerpc/booke/e500_timer.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/powerpc/booke/e500_timer.c
diff -u src/sys/arch/powerpc/booke/e500_timer.c:1.5 src/sys/arch/powerpc/booke/e500_timer.c:1.5.2.1
--- src/sys/arch/powerpc/booke/e500_timer.c:1.5	Tue Jul 29 23:35:00 2014
+++ src/sys/arch/powerpc/booke/e500_timer.c	Mon Jan 26 16:18:42 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: e500_timer.c,v 1.5 2014/07/29 23:35:00 joerg Exp $	*/
+/*	$NetBSD: e500_timer.c,v 1.5.2.1 2015/01/26 16:18:42 martin Exp $	*/
 /*-
  * Copyright (c) 2010, 2011 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -35,7 +35,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: e500_timer.c,v 1.5 2014/07/29 23:35:00 joerg Exp $);
+__KERNEL_RCSID(0, $NetBSD: e500_timer.c,v 1.5.2.1 2015/01/26 16:18:42 martin Exp $);
 
 #include sys/param.h
 #include sys/kernel.h
@@ -53,6 +53,7 @@ __KERNEL_RCSID(0, $NetBSD: e500_timer.c
 #include powerpc/booke/e500var.h
 #include powerpc/booke/openpicreg.h
 
+uint32_t ticks_per_sec;
 static u_long ns_per_tick;
 
 static void init_ppcbooke_tc(void);
@@ -173,6 +174,7 @@ calc_delayconst(void)
 	struct cpu_info * const ci = curcpu();
 
 	ci-ci_data.cpu_cc_freq = board_info_get_number(timebase-frequency);
+	ticks_per_sec = (uint32_t)ci-ci_data.cpu_cc_freq;
 	ns_per_tick = 10 / (u_int)ci-ci_data.cpu_cc_freq;
 }
 



CVS commit: [netbsd-7] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 16:24:28 UTC 2015

Modified Files:
src/doc [netbsd-7]: CHANGES-7.0

Log Message:
Tickets #455 - #458


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.180 -r1.1.2.181 src/doc/CHANGES-7.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-7.0
diff -u src/doc/CHANGES-7.0:1.1.2.180 src/doc/CHANGES-7.0:1.1.2.181
--- src/doc/CHANGES-7.0:1.1.2.180	Sun Jan 25 09:48:43 2015
+++ src/doc/CHANGES-7.0	Mon Jan 26 16:24:28 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-7.0,v 1.1.2.180 2015/01/25 09:48:43 martin Exp $
+# $NetBSD: CHANGES-7.0,v 1.1.2.181 2015/01/26 16:24:28 martin Exp $
 
 A complete list of changes from the initial NetBSD 7.0 branch on 11 Aug 2014
 until the 7.0 release:
@@ -15027,3 +15027,29 @@ sys/arch/arm/arm/db_trace.c			1.31
 	Fix crash(8) backtrace support.
 	[skrll, ticket #454]
 
+sys/arch/x86/pci/ichlpcib.c			1.46
+
+	The PMBASE and GPIOBASE registers are not compatible with
+	the PCI spec and the map sizes are fixed to 128bytes. The
+	pci_mapreg_submap() function has a code to check the range
+	of the BAR. The PCI_MAPREG_IO_SIZE() macro returns lower
+	than 128bytes on some machines. This makes iz impossible to
+	use pci_mapreg_submap(). Use pci_conf_read() and
+	bus_space_map() directly.
+	[msaitoh, ticket #455]
+
+sys/arch/powerpc/booke/e500_timer.c		1.6
+
+	Fix build failure with lockstat.
+	[nonaka, ticket #456]
+
+external/mit/xorg/lib/freetype/Makefile		1.13
+
+	Fix PKG_CONFIG version after freetype2-2.5.3 import.
+	[wiz, ticket #457]
+
+external/gpl3/gcc/dist/libsanitizer/tsan/tsan_rtl_amd64.S 1.2
+
+	Fix for PIC code.
+	[skrll, ticket #458]
+



CVS commit: [netbsd-6] src/sys/arch/x86/x86

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 14:02:40 UTC 2015

Modified Files:
src/sys/arch/x86/x86 [netbsd-6]: identcpu.c

Log Message:
Pull up the following, requested by msaitoh in ticket #1241:

sys/arch/x86/x86/identcpu.c 1.35-1.39

- Check cpuid leaf 4 for newer Intel CPU to know the cache information.
  This code might improve performance because it changes the number of
  page colors.
- Fix calculation of the cpu model (display model) in
  cpu_probe_amd_cache().
- CPUID leaf 2 and 4 are only for Intel processors.


To generate a diff of this commit:
cvs rdiff -u -r1.29.2.2 -r1.29.2.3 src/sys/arch/x86/x86/identcpu.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/x86/x86/identcpu.c
diff -u src/sys/arch/x86/x86/identcpu.c:1.29.2.2 src/sys/arch/x86/x86/identcpu.c:1.29.2.3
--- src/sys/arch/x86/x86/identcpu.c:1.29.2.2	Mon May  7 16:37:19 2012
+++ src/sys/arch/x86/x86/identcpu.c	Mon Jan 26 14:02:40 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: identcpu.c,v 1.29.2.2 2012/05/07 16:37:19 riz Exp $	*/
+/*	$NetBSD: identcpu.c,v 1.29.2.3 2015/01/26 14:02:40 martin Exp $	*/
 
 /*-
  * Copyright (c) 1999, 2000, 2001, 2006, 2007, 2008 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: identcpu.c,v 1.29.2.2 2012/05/07 16:37:19 riz Exp $);
+__KERNEL_RCSID(0, $NetBSD: identcpu.c,v 1.29.2.3 2015/01/26 14:02:40 martin Exp $);
 
 #include opt_xen.h
 
@@ -97,6 +97,103 @@ cache_info_lookup(const struct x86_cache
 	return (NULL);
 }
 
+static void
+cpu_probe_intel_cache(struct cpu_info *ci)
+{
+	const struct x86_cache_info *cai;
+	u_int descs[4];
+	int iterations, i, j;
+	uint8_t desc;
+
+	if (cpuid_level = 2) { 
+		/* Parse the cache info from `cpuid leaf 2', if we have it. */
+		x86_cpuid(2, descs);
+		iterations = descs[0]  0xff;
+		while (iterations--  0) {
+			for (i = 0; i  4; i++) {
+if (descs[i]  0x8000)
+	continue;
+for (j = 0; j  4; j++) {
+	if (i == 0  j == 0)
+		continue;
+	desc = (descs[i]  (j * 8))  0xff;
+	if (desc == 0)
+		continue;
+	cai = cache_info_lookup(
+	intel_cpuid_cache_info, desc);
+	if (cai != NULL) {
+		ci-ci_cinfo[cai-cai_index] =
+		*cai;
+	}
+}
+			}
+		}
+	}
+
+	if (cpuid_level = 4) {
+		int type, level;
+		int ways, partitions, linesize, sets;
+		int caitype = -1;
+		int totalsize;
+		
+		/* Parse the cache info from `cpuid leaf 4', if we have it. */
+		for (i = 0; ; i++) {
+			x86_cpuid2(4, i, descs);
+			type = __SHIFTOUT(descs[0], CPUID_DCP_CACHETYPE);
+			if (type == CPUID_DCP_CACHETYPE_N)
+break;
+			level = __SHIFTOUT(descs[0], CPUID_DCP_CACHELEVEL);
+			switch (level) {
+			case 1:
+if (type == CPUID_DCP_CACHETYPE_I)
+	caitype = CAI_ICACHE;
+else if (type == CPUID_DCP_CACHETYPE_D)
+	caitype = CAI_DCACHE;
+else
+	caitype = -1;
+break;
+			case 2:
+if (type == CPUID_DCP_CACHETYPE_U)
+	caitype = CAI_L2CACHE;
+else
+	caitype = -1;
+break;
+			case 3:
+if (type == CPUID_DCP_CACHETYPE_U)
+	caitype = CAI_L3CACHE;
+else
+	caitype = -1;
+break;
+			default:
+caitype = -1;
+break;
+			}
+			if (caitype == -1)
+continue;
+
+			ways = __SHIFTOUT(descs[1], CPUID_DCP_WAYS) + 1;
+			partitions =__SHIFTOUT(descs[1], CPUID_DCP_PARTITIONS)
+			+ 1;
+			linesize = __SHIFTOUT(descs[1], CPUID_DCP_LINESIZE)
+			+ 1;
+			sets = descs[2] + 1;
+			totalsize = ways * partitions * linesize * sets;
+			ci-ci_cinfo[caitype].cai_totalsize = totalsize;
+			ci-ci_cinfo[caitype].cai_associativity = ways;
+			ci-ci_cinfo[caitype].cai_linesize = linesize;
+		}
+	}
+}
+
+static void
+cpu_probe_intel(struct cpu_info *ci)
+{
+
+	if (cpu_vendor != CPUVENDOR_INTEL)
+		return;
+
+	cpu_probe_intel_cache(ci);
+}
 
 static void
 cpu_probe_amd_cache(struct cpu_info *ci)
@@ -107,8 +204,8 @@ cpu_probe_amd_cache(struct cpu_info *ci)
 	u_int descs[4];
 	u_int lfunc;
 
-	family = CPUID2FAMILY(ci-ci_signature);
-	model = CPUID2MODEL(ci-ci_signature);
+	family = CPUID_TO_FAMILY(ci-ci_signature);
+	model = CPUID_TO_MODEL(ci-ci_signature);
 
 	/*
 	 * K5 model 0 has none of this info.
@@ -117,14 +214,6 @@ cpu_probe_amd_cache(struct cpu_info *ci)
 		return;
 
 	/*
-	 * Get extended values for K8 and up.
-	 */
-	if (family == 0xf) {
-		family += CPUID2EXTFAMILY(ci-ci_signature);
-		model += CPUID2EXTMODEL(ci-ci_signature);
-	}
-
-	/*
 	 * Determine the largest extended function value.
 	 */
 	x86_cpuid(0x8000, descs);
@@ -248,10 +337,10 @@ cpu_probe_k5(struct cpu_info *ci)
 	int flag;
 
 	if (cpu_vendor != CPUVENDOR_AMD ||
-	CPUID2FAMILY(ci-ci_signature) != 5)
+	CPUID_TO_FAMILY(ci-ci_signature) != 5)
 		return;
 
-	if (CPUID2MODEL(ci-ci_signature) == 0) {
+	if (CPUID_TO_MODEL(ci-ci_signature) == 0) {
 		/*
 		 * According to the AMD Processor Recognition App Note,

CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 20:32:18 UTC 2015

Modified Files:
src/sys/dev/usb: uaudio.c

Log Message:
When dumping iot[] contents to the console for debugging, don't crash
if iot[i].output is NULL for some i.  Share code with the dumping of
iot[i].inputs[], which already handled NULLs.


To generate a diff of this commit:
cvs rdiff -u -r1.141 -r1.142 src/sys/dev/usb/uaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uaudio.c
diff -u src/sys/dev/usb/uaudio.c:1.141 src/sys/dev/usb/uaudio.c:1.142
--- src/sys/dev/usb/uaudio.c:1.141	Mon Jan 26 09:25:08 2015
+++ src/sys/dev/usb/uaudio.c	Mon Jan 26 20:32:17 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uaudio.c,v 1.141 2015/01/26 09:25:08 gson Exp $	*/
+/*	$NetBSD: uaudio.c,v 1.142 2015/01/26 20:32:17 gson Exp $	*/
 
 /*
  * Copyright (c) 1999, 2012 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.141 2015/01/26 09:25:08 gson Exp $);
+__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.142 2015/01/26 20:32:17 gson Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_usb.h
@@ -252,6 +252,10 @@ Static const char *uac_names[] = {
 };
 #endif
 
+#ifdef UAUDIO_DEBUG
+Static void uaudio_dump_tml
+	(struct terminal_list *tml);
+#endif
 Static usbd_status uaudio_identify_ac
 	(struct uaudio_softc *, const usb_config_descriptor_t *);
 Static usbd_status uaudio_identify_as
@@ -1872,6 +1876,21 @@ uaudio_identify_as(struct uaudio_softc *
 	return USBD_NORMAL_COMPLETION;
 }
 
+#ifdef UAUDIO_DEBUG
+Static void
+uaudio_dump_tml(struct terminal_list *tml) {
+	if (tml == NULL) {
+		printf(NULL);
+	} else {
+int i;
+		for (i = 0; i  tml-size; i++)
+			printf(%s , uaudio_get_terminal_name
+			   (tml-terminals[i]));
+	}
+	printf(\n);
+}
+#endif
+
 Static usbd_status
 uaudio_identify_ac(struct uaudio_softc *sc, const usb_config_descriptor_t *cdesc)
 {
@@ -2015,23 +2034,11 @@ uaudio_identify_ac(struct uaudio_softc *
   iot[i].d.desc-bDescriptorSubtype);
 		}
 		for (j = 0; j  iot[i].inputs_size; j++) {
-			int k;
 			printf(\tinput%d: , j);
-			tml = iot[i].inputs[j];
-			if (tml == NULL) {
-printf(NULL\n);
-continue;
-			}
-			for (k = 0; k  tml-size; k++)
-printf(%s , uaudio_get_terminal_name
-	  (tml-terminals[k]));
-			printf(\n);
+			uaudio_dump_tml(iot[i].inputs[j]);
 		}
 		printf(\toutput: );
-		tml = iot[i].output;
-		for (j = 0; j  tml-size; j++)
-			printf(%s , uaudio_get_terminal_name(tml-terminals[j]));
-		printf(\n);
+		uaudio_dump_tml(iot[i].output);
 	}
 #endif
 



CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 20:37:44 UTC 2015

Modified Files:
src/sys/dev/usb: uaudio.c

Log Message:
Don't crash with a division by zero if a bControlSize field is 0.


To generate a diff of this commit:
cvs rdiff -u -r1.142 -r1.143 src/sys/dev/usb/uaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uaudio.c
diff -u src/sys/dev/usb/uaudio.c:1.142 src/sys/dev/usb/uaudio.c:1.143
--- src/sys/dev/usb/uaudio.c:1.142	Mon Jan 26 20:32:17 2015
+++ src/sys/dev/usb/uaudio.c	Mon Jan 26 20:37:44 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uaudio.c,v 1.142 2015/01/26 20:32:17 gson Exp $	*/
+/*	$NetBSD: uaudio.c,v 1.143 2015/01/26 20:37:44 gson Exp $	*/
 
 /*
  * Copyright (c) 1999, 2012 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.142 2015/01/26 20:32:17 gson Exp $);
+__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.143 2015/01/26 20:37:44 gson Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_usb.h
@@ -1122,6 +1122,10 @@ uaudio_add_feature(struct uaudio_softc *
 	d = iot[id].d.fu;
 	ctls = d-bmaControls;
 	ctlsize = d-bControlSize;
+	if (ctlsize == 0) {
+		DPRINTF(ignoring feature %d with controlSize of zero\n, id);
+		return;
+	}
 	nchan = (d-bLength - 7) / ctlsize;
 	mmask = GET(0);
 	/* Figure out what we can control */



CVS commit: src/share/man/man4

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 20:41:49 UTC 2015

Modified Files:
src/share/man/man4: uaudio.4

Log Message:
Fix URL of USB Approved Class Specification Documents.


To generate a diff of this commit:
cvs rdiff -u -r1.25 -r1.26 src/share/man/man4/uaudio.4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man4/uaudio.4
diff -u src/share/man/man4/uaudio.4:1.25 src/share/man/man4/uaudio.4:1.26
--- src/share/man/man4/uaudio.4:1.25	Tue Sep 20 19:31:47 2011
+++ src/share/man/man4/uaudio.4	Mon Jan 26 20:41:49 2015
@@ -1,4 +1,4 @@
-.\ $NetBSD: uaudio.4,v 1.25 2011/09/20 19:31:47 wiz Exp $
+.\ $NetBSD: uaudio.4,v 1.26 2015/01/26 20:41:49 gson Exp $
 .\
 .\ Copyright (c) 1999 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -111,7 +111,7 @@ reading.
 .Xr usb 4
 .Rs
 .%T USB Approved Class Specification Documents
-.%U http://www.usb.org/developers/devclass_docs/
+.%U http://www.usb.org/developers/docs/devclass_docs/
 .Re
 .Sh HISTORY
 The



CVS commit: src/libexec/httpd

2015-01-26 Thread Soren Jacobsen
Module Name:src
Committed By:   snj
Date:   Tue Jan 27 04:20:24 UTC 2015

Modified Files:
src/libexec/httpd: bozohttpd.c

Log Message:
spit out a 403 not just when an open() fails with EPERM, but with
EACCES as well.


To generate a diff of this commit:
cvs rdiff -u -r1.60 -r1.61 src/libexec/httpd/bozohttpd.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/libexec/httpd/bozohttpd.c
diff -u src/libexec/httpd/bozohttpd.c:1.60 src/libexec/httpd/bozohttpd.c:1.61
--- src/libexec/httpd/bozohttpd.c:1.60	Thu Dec 25 18:53:06 2014
+++ src/libexec/httpd/bozohttpd.c	Tue Jan 27 04:20:23 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: bozohttpd.c,v 1.60 2014/12/25 18:53:06 mrg Exp $	*/
+/*	$NetBSD: bozohttpd.c,v 1.61 2015/01/27 04:20:23 snj Exp $	*/
 
 /*	$eterna: bozohttpd.c,v 1.178 2011/11/18 09:21:15 mrg Exp $	*/
 
@@ -1566,6 +1566,7 @@ bozo_process_request(bozo_httpreq_t *req
 		debug((httpd, DEBUG_FAT, open failed: %s, strerror(errno)));
 		switch(errno) {
 		case EPERM:
+		case EACCES:
 			(void)bozo_http_error(httpd, 403, request,
 		no permission to open file);
 			break;



CVS commit: src/external/bsd/ntp/dist/ntpd

2015-01-26 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Tue Jan 27 02:37:18 UTC 2015

Modified Files:
src/external/bsd/ntp/dist/ntpd: refclock_parse.c

Log Message:
put back initialization of the buffer which was accidentally removed.
XXX: pullup-7.


To generate a diff of this commit:
cvs rdiff -u -r1.13 -r1.14 src/external/bsd/ntp/dist/ntpd/refclock_parse.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/ntp/dist/ntpd/refclock_parse.c
diff -u src/external/bsd/ntp/dist/ntpd/refclock_parse.c:1.13 src/external/bsd/ntp/dist/ntpd/refclock_parse.c:1.14
--- src/external/bsd/ntp/dist/ntpd/refclock_parse.c:1.13	Fri Dec 19 15:43:17 2014
+++ src/external/bsd/ntp/dist/ntpd/refclock_parse.c	Mon Jan 26 21:37:18 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: refclock_parse.c,v 1.13 2014/12/19 20:43:17 christos Exp $	*/
+/*	$NetBSD: refclock_parse.c,v 1.14 2015/01/27 02:37:18 christos Exp $	*/
 
 /*
  * /src/NTP/REPOSITORY/ntp4-dev/ntpd/refclock_parse.c,v 4.81 2009/05/01 10:15:29 kardel RELEASE_20090105_A
@@ -2535,6 +2535,7 @@ parsestate(
 	int i;
 	char *s, *t;
 
+	*buffer = '\0';
 	s = t = buffer;
 
 	i = 0;



CVS commit: [netbsd-7] src/external/gpl3/gcc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Tue Jan 27 07:38:26 UTC 2015

Modified Files:
src/external/gpl3/gcc/lib/libstdc++-v3/arch/arm [netbsd-7]: gstdint.h
src/external/gpl3/gcc/usr.bin/gcc/arch/alpha [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/arm [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/armeb [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earm [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmeb [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmhf [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmhfeb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv4 [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv4eb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6 [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6eb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6hf [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6hfeb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7 [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7eb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7hf [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7hfeb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/hppa [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/i386 [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/m68000 [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/m68k [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/mips64eb [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/mips64el [netbsd-7]:
configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/mipseb [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/mipsel [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/powerpc [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/sh3eb [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/sh3el [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/sparc [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/sparc64 [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/vax [netbsd-7]: configargs.h
src/external/gpl3/gcc/usr.bin/gcc/arch/x86_64 [netbsd-7]: configargs.h

Log Message:
Regen (mknative results part 2) for #448


To generate a diff of this commit:
cvs rdiff -u -r1.6.2.2 -r1.6.2.3 \
src/external/gpl3/gcc/lib/libstdc++-v3/arch/arm/gstdint.h
cvs rdiff -u -r1.11.2.2 -r1.11.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/alpha/configargs.h
cvs rdiff -u -r1.13.2.2 -r1.13.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/arm/configargs.h
cvs rdiff -u -r1.13.2.2 -r1.13.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/armeb/configargs.h
cvs rdiff -u -r1.11.2.2 -r1.11.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earm/configargs.h
cvs rdiff -u -r1.7.2.2 -r1.7.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmeb/configargs.h
cvs rdiff -u -r1.8.2.2 -r1.8.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmhf/configargs.h
cvs rdiff -u -r1.6.2.2 -r1.6.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmhfeb/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv4/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv4eb/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6eb/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6hf/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv6hfeb/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7eb/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7hf/configargs.h
cvs rdiff -u -r1.5.2.2 -r1.5.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/earmv7hfeb/configargs.h
cvs rdiff -u -r1.12.2.2 -r1.12.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/hppa/configargs.h
cvs rdiff -u -r1.15.2.2 -r1.15.2.3 \
src/external/gpl3/gcc/usr.bin/gcc/arch/i386/configargs.h
cvs rdiff -u -r1.9.4.1 -r1.9.4.2 \

CVS commit: [netbsd-7] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Tue Jan 27 07:49:48 UTC 2015

Modified Files:
src/doc [netbsd-7]: CHANGES-7.0

Log Message:
Update ticket #448 for additionally regenerated files (patch - regen)


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.181 -r1.1.2.182 src/doc/CHANGES-7.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-7.0
diff -u src/doc/CHANGES-7.0:1.1.2.181 src/doc/CHANGES-7.0:1.1.2.182
--- src/doc/CHANGES-7.0:1.1.2.181	Mon Jan 26 16:24:28 2015
+++ src/doc/CHANGES-7.0	Tue Jan 27 07:49:48 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-7.0,v 1.1.2.181 2015/01/26 16:24:28 martin Exp $
+# $NetBSD: CHANGES-7.0,v 1.1.2.182 2015/01/27 07:49:48 martin Exp $
 
 A complete list of changes from the initial NetBSD 7.0 branch on 11 Aug 2014
 until the 7.0 release:
@@ -14796,117 +14796,83 @@ external/gpl3/gcc/usr.bin/Makefile  
 external/gpl3/gcc/usr.bin/backend/Makefile  up to 1.23
 external/gpl3/gcc/usr.bin/frontend/Makefile up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/alpha/auto-host.h up to 1.5
-external/gpl3/gcc/usr.bin/gcc/arch/alpha/configargs.h up to 1.15
 external/gpl3/gcc/usr.bin/gcc/arch/alpha/plugin-version.h up to 1.7
 external/gpl3/gcc/usr.bin/gcc/arch/arm/auto-host.h up to 1.5
-external/gpl3/gcc/usr.bin/gcc/arch/arm/configargs.h up to 1.17
 external/gpl3/gcc/usr.bin/gcc/arch/arm/plugin-version.h up to 1.7
 external/gpl3/gcc/usr.bin/gcc/arch/armeb/auto-host.h up to 1.6
-external/gpl3/gcc/usr.bin/gcc/arch/armeb/configargs.h up to 1.17
 external/gpl3/gcc/usr.bin/gcc/arch/armeb/plugin-version.h up to 1.7
 external/gpl3/gcc/usr.bin/gcc/arch/coldfire/auto-host.h up to 1.5
 external/gpl3/gcc/usr.bin/gcc/arch/coldfire/bversion.h up to 1.3
-external/gpl3/gcc/usr.bin/gcc/arch/coldfire/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/coldfire/defs.mk up to 1.5
 external/gpl3/gcc/usr.bin/gcc/arch/coldfire/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/coldfire/tm.h up to 1.3
 external/gpl3/gcc/usr.bin/gcc/arch/earm/auto-host.h up to 1.7
-external/gpl3/gcc/usr.bin/gcc/arch/earm/configargs.h up to 1.15
 external/gpl3/gcc/usr.bin/gcc/arch/earm/plugin-version.h up to 1.7
 external/gpl3/gcc/usr.bin/gcc/arch/earmeb/auto-host.h up to 1.5
-external/gpl3/gcc/usr.bin/gcc/arch/earmeb/configargs.h up to 1.11
 external/gpl3/gcc/usr.bin/gcc/arch/earmeb/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmhf/auto-host.h up to 1.6
-external/gpl3/gcc/usr.bin/gcc/arch/earmhf/configargs.h up to 1.12
 external/gpl3/gcc/usr.bin/gcc/arch/earmhf/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmhfeb/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmhfeb/configargs.h up to 1.10
 external/gpl3/gcc/usr.bin/gcc/arch/earmhfeb/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv4/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv4/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv4/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv4eb/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv4eb/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv4eb/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv6/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6eb/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv6eb/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6eb/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6hf/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv6hf/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6hf/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6hfeb/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv6hfeb/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv6hfeb/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv7/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7eb/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv7eb/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7eb/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7hf/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv7hf/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7hf/plugin-version.h up to 1.6
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7hfeb/auto-host.h up to 1.4
-external/gpl3/gcc/usr.bin/gcc/arch/earmv7hfeb/configargs.h up to 1.9
 external/gpl3/gcc/usr.bin/gcc/arch/earmv7hfeb/plugin-version.h up to 1.6
 

CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 09:58:10 UTC 2015

Modified Files:
src/sys/dev/usb: usbdevs

Log Message:
Add Silicon Labs EC3 USB debug adapter.


To generate a diff of this commit:
cvs rdiff -u -r1.687 -r1.688 src/sys/dev/usb/usbdevs

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevs
diff -u src/sys/dev/usb/usbdevs:1.687 src/sys/dev/usb/usbdevs:1.688
--- src/sys/dev/usb/usbdevs:1.687	Wed Dec 17 10:02:01 2014
+++ src/sys/dev/usb/usbdevs	Mon Jan 26 09:58:10 2015
@@ -1,4 +1,4 @@
-$NetBSD: usbdevs,v 1.687 2014/12/17 10:02:01 jnemeth Exp $
+$NetBSD: usbdevs,v 1.688 2015/01/26 09:58:10 gson Exp $
 
 /*
  * Copyright (c) 1998-2004 The NetBSD Foundation, Inc.
@@ -2911,6 +2911,7 @@ product SILABS LIPOWSKY_HARP	0x8218	Lipo
 product SILABS2 DCU11CLONE	0xaa26	DCU-11 clone
 product SILABS CP210X_1		0xea60	CP210x Serial
 product SILABS CP210X_2		0xea61	CP210x Serial
+product SILABS EC3		0x8044  EC3 USB Debug Adapter
 
 /* Silicon Portals Inc. */
 product SILICONPORTALS YAPPH_NF 0x0200	YAP Phone (no firmware)



CVS commit: [netbsd-5] src

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 10:10:20 UTC 2015

Modified Files:
src/crypto/dist/openssl/apps [netbsd-5]: s_client.c s_server.c speed.c
src/crypto/dist/openssl/crypto [netbsd-5]: Makefile
constant_time_locl.h cversion.c
src/crypto/dist/openssl/crypto/asn1 [netbsd-5]: a_bitstr.c a_type.c
a_verify.c asn1.h asn1_err.c tasn_dec.c x_algor.c
src/crypto/dist/openssl/crypto/bio [netbsd-5]: bio.h bss_dgram.c
src/crypto/dist/openssl/crypto/bn [netbsd-5]: bn_asm.c bntest.c
src/crypto/dist/openssl/crypto/bn/asm [netbsd-5]: mips3.s x86_64-gcc.c
src/crypto/dist/openssl/crypto/dsa [netbsd-5]: dsa_vrf.c
src/crypto/dist/openssl/crypto/ec [netbsd-5]: ec_mult.c ec_pmeth.c
src/crypto/dist/openssl/crypto/ecdsa [netbsd-5]: ecs_vrf.c
src/crypto/dist/openssl/crypto/evp [netbsd-5]: Makefile evp_enc.c
src/crypto/dist/openssl/crypto/objects [netbsd-5]: obj_xref.h
objxref.pl
src/crypto/dist/openssl/crypto/ts [netbsd-5]: ts_rsp_sign.c
src/crypto/dist/openssl/crypto/x509 [netbsd-5]: x509.h x509_vpm.c
x_all.c
src/crypto/dist/openssl/ssl [netbsd-5]: d1_both.c d1_clnt.c d1_enc.c
d1_lib.c d1_pkt.c d1_srvr.c dtls1.h s23_srvr.c s2_enc.c s2_pkt.c
s2_srvr.c s3_both.c s3_clnt.c s3_enc.c s3_lib.c s3_pkt.c s3_srvr.c
ssl.h ssl_cert.c ssl_lib.c ssl_locl.h
src/crypto/dist/openssl/util [netbsd-5]: libeay.num mk1mf.pl
src/distrib/sets/lists/base [netbsd-5]: md.amd64 md.sparc64 shl.mi
src/lib/libcrypto [netbsd-5]: shlib_version
src/lib/libssl [netbsd-5]: shlib_version

Log Message:
Change the following, requested by spz in ticket #1945:
crypto/dist/openssl/apps/s_client.c  patch
crypto/dist/openssl/apps/s_server.c  patch
crypto/dist/openssl/apps/speed.c patch
crypto/dist/openssl/crypto/Makefile  patch
crypto/dist/openssl/crypto/constant_time_locl.h  patch
crypto/dist/openssl/crypto/cversion.cpatch
crypto/dist/openssl/crypto/asn1/a_bitstr.c   patch
crypto/dist/openssl/crypto/asn1/a_type.c patch
crypto/dist/openssl/crypto/asn1/a_verify.c   patch
crypto/dist/openssl/crypto/asn1/asn1.h   patch
crypto/dist/openssl/crypto/asn1/asn1_err.c   patch
crypto/dist/openssl/crypto/asn1/tasn_dec.c   patch
crypto/dist/openssl/crypto/asn1/x_algor.cpatch
crypto/dist/openssl/crypto/bio/bio.h patch
crypto/dist/openssl/crypto/bio/bss_dgram.c   patch
crypto/dist/openssl/crypto/bn/bn_asm.c   patch
crypto/dist/openssl/crypto/bn/bntest.c   patch
crypto/dist/openssl/crypto/bn/asm/mips3.spatch
crypto/dist/openssl/crypto/bn/asm/x86_64-gcc.c   patch
crypto/dist/openssl/crypto/dsa/dsa_vrf.c patch
crypto/dist/openssl/crypto/ec/ec_mult.c  patch
crypto/dist/openssl/crypto/ec/ec_pmeth.c patch
crypto/dist/openssl/crypto/ecdsa/ecs_vrf.c   patch
crypto/dist/openssl/crypto/evp/Makefile  patch
crypto/dist/openssl/crypto/evp/evp_enc.c patch
crypto/dist/openssl/crypto/objects/obj_xref.hpatch
crypto/dist/openssl/crypto/objects/objxref.plpatch
crypto/dist/openssl/crypto/ts/ts_rsp_sign.c  patch
crypto/dist/openssl/crypto/x509/x509.h   patch
crypto/dist/openssl/crypto/x509/x509_vpm.c   patch
crypto/dist/openssl/crypto/x509/x_all.c  patch
crypto/dist/openssl/ssl/d1_both.cpatch
crypto/dist/openssl/ssl/d1_clnt.cpatch
crypto/dist/openssl/ssl/d1_enc.c patch
crypto/dist/openssl/ssl/d1_lib.c patch
crypto/dist/openssl/ssl/d1_pkt.c patch
crypto/dist/openssl/ssl/d1_srvr.cpatch
crypto/dist/openssl/ssl/dtls1.h  patch
crypto/dist/openssl/ssl/s23_srvr.c   patch
crypto/dist/openssl/ssl/s2_enc.c patch
crypto/dist/openssl/ssl/s2_pkt.c patch
crypto/dist/openssl/ssl/s2_srvr.cpatch
crypto/dist/openssl/ssl/s3_both.c

CVS commit: [netbsd-5] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 10:11:20 UTC 2015

Modified Files:
src/doc [netbsd-5]: CHANGES-5.3

Log Message:
Ticket #1945


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.93 -r1.1.2.94 src/doc/CHANGES-5.3

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-5.3
diff -u src/doc/CHANGES-5.3:1.1.2.93 src/doc/CHANGES-5.3:1.1.2.94
--- src/doc/CHANGES-5.3:1.1.2.93	Fri Jan 23 16:27:46 2015
+++ src/doc/CHANGES-5.3	Mon Jan 26 10:11:20 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-5.3,v 1.1.2.93 2015/01/23 16:27:46 martin Exp $
+# $NetBSD: CHANGES-5.3,v 1.1.2.94 2015/01/26 10:11:20 martin Exp $
 
 A complete list of changes from the NetBSD 5.2 release to the NetBSD 5.3
 release:
@@ -3630,3 +3630,75 @@ sys/dev/pci/pci_map.c			1.32 via patch
 	[msaitoh, ticket #1942]
 
 
+crypto/dist/openssl/apps/s_client.c   patch
+crypto/dist/openssl/apps/s_server.c   patch
+crypto/dist/openssl/apps/speed.c  patch
+crypto/dist/openssl/crypto/Makefile   patch
+crypto/dist/openssl/crypto/constant_time_locl.h   patch
+crypto/dist/openssl/crypto/cversion.c patch
+crypto/dist/openssl/crypto/asn1/a_bitstr.cpatch
+crypto/dist/openssl/crypto/asn1/a_type.c  patch
+crypto/dist/openssl/crypto/asn1/a_verify.cpatch
+crypto/dist/openssl/crypto/asn1/asn1.hpatch
+crypto/dist/openssl/crypto/asn1/asn1_err.cpatch
+crypto/dist/openssl/crypto/asn1/tasn_dec.cpatch
+crypto/dist/openssl/crypto/asn1/x_algor.c patch
+crypto/dist/openssl/crypto/bio/bio.h  patch
+crypto/dist/openssl/crypto/bio/bss_dgram.cpatch
+crypto/dist/openssl/crypto/bn/bn_asm.cpatch
+crypto/dist/openssl/crypto/bn/bntest.cpatch
+crypto/dist/openssl/crypto/bn/asm/mips3.s patch
+crypto/dist/openssl/crypto/bn/asm/x86_64-gcc.cpatch
+crypto/dist/openssl/crypto/dsa/dsa_vrf.c  patch
+crypto/dist/openssl/crypto/ec/ec_mult.c   patch
+crypto/dist/openssl/crypto/ec/ec_pmeth.c  patch
+crypto/dist/openssl/crypto/ecdsa/ecs_vrf.cpatch
+crypto/dist/openssl/crypto/evp/Makefile   patch
+crypto/dist/openssl/crypto/evp/evp_enc.c  patch
+crypto/dist/openssl/crypto/objects/obj_xref.h patch
+crypto/dist/openssl/crypto/objects/objxref.pl patch
+crypto/dist/openssl/crypto/ts/ts_rsp_sign.c   patch
+crypto/dist/openssl/crypto/x509/x509.hpatch
+crypto/dist/openssl/crypto/x509/x509_vpm.cpatch
+crypto/dist/openssl/crypto/x509/x_all.c   patch
+crypto/dist/openssl/ssl/d1_both.c patch
+crypto/dist/openssl/ssl/d1_clnt.c patch
+crypto/dist/openssl/ssl/d1_enc.c  patch
+crypto/dist/openssl/ssl/d1_lib.c  patch
+crypto/dist/openssl/ssl/d1_pkt.c  patch
+crypto/dist/openssl/ssl/d1_srvr.c patch
+crypto/dist/openssl/ssl/dtls1.h   patch
+crypto/dist/openssl/ssl/s23_srvr.cpatch
+crypto/dist/openssl/ssl/s2_enc.c  patch
+crypto/dist/openssl/ssl/s2_pkt.c  patch
+crypto/dist/openssl/ssl/s2_srvr.c patch
+crypto/dist/openssl/ssl/s3_both.c patch
+crypto/dist/openssl/ssl/s3_clnt.c patch
+crypto/dist/openssl/ssl/s3_enc.c  patch
+crypto/dist/openssl/ssl/s3_lib.c  patch
+crypto/dist/openssl/ssl/s3_pkt.c  patch
+crypto/dist/openssl/ssl/s3_srvr.c patch
+crypto/dist/openssl/ssl/ssl.h patch
+crypto/dist/openssl/ssl/ssl_cert.cpatch
+crypto/dist/openssl/ssl/ssl_lib.c patch
+crypto/dist/openssl/ssl/ssl_locl.hpatch
+crypto/dist/openssl/util/libeay.num   patch
+crypto/dist/openssl/util/mk1mf.pl patch
+crypto/dist/openssl/util/mkbuildinf.plpatch
+distrib/sets/lists/base/md.amd64   

CVS commit: src/sys/arch/evbarm/ifpga

2015-01-26 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Jan 26 08:55:41 UTC 2015

Modified Files:
src/sys/arch/evbarm/ifpga: ifpgareg.h

Log Message:
Don't mask irq 23


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/arch/evbarm/ifpga/ifpgareg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/ifpga/ifpgareg.h
diff -u src/sys/arch/evbarm/ifpga/ifpgareg.h:1.5 src/sys/arch/evbarm/ifpga/ifpgareg.h:1.6
--- src/sys/arch/evbarm/ifpga/ifpgareg.h:1.5	Tue Feb 19 10:57:10 2013
+++ src/sys/arch/evbarm/ifpga/ifpgareg.h	Mon Jan 26 08:55:41 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: ifpgareg.h,v 1.5 2013/02/19 10:57:10 skrll Exp $ */
+/*	$NetBSD: ifpgareg.h,v 1.6 2015/01/26 08:55:41 skrll Exp $ */
 
 /*
  * Copyright (c) 2001 ARM Ltd
@@ -212,7 +212,7 @@
 #define IFPGA_INTR_SOFTINT		0x0001
 
 #if defined(INTEGRATOR_CP)
-#define IFPGA_INTR_HWMASK		0x083f
+#define IFPGA_INTR_HWMASK		0x08bf
 #else
 #define IFPGA_INTR_HWMASK		0x003f
 #endif



CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 09:25:09 UTC 2015

Modified Files:
src/sys/dev/usb: uaudio.c

Log Message:
Include opt_usb.h so that options UAUDIO_DEBUG works.


To generate a diff of this commit:
cvs rdiff -u -r1.140 -r1.141 src/sys/dev/usb/uaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uaudio.c
diff -u src/sys/dev/usb/uaudio.c:1.140 src/sys/dev/usb/uaudio.c:1.141
--- src/sys/dev/usb/uaudio.c:1.140	Mon Sep 22 14:25:32 2014
+++ src/sys/dev/usb/uaudio.c	Mon Jan 26 09:25:08 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uaudio.c,v 1.140 2014/09/22 14:25:32 nat Exp $	*/
+/*	$NetBSD: uaudio.c,v 1.141 2015/01/26 09:25:08 gson Exp $	*/
 
 /*
  * Copyright (c) 1999, 2012 The NetBSD Foundation, Inc.
@@ -37,7 +37,11 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.140 2014/09/22 14:25:32 nat Exp $);
+__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.141 2015/01/26 09:25:08 gson Exp $);
+
+#ifdef _KERNEL_OPT
+#include opt_usb.h
+#endif
 
 #include sys/param.h
 #include sys/systm.h



CVS commit: src/external/mit/xorg/lib/freetype

2015-01-26 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Mon Jan 26 08:47:25 UTC 2015

Modified Files:
src/external/mit/xorg/lib/freetype: Makefile

Log Message:
Fix PKG_CONFIG version after freetype2-2.5.3 import.

From Leonardo Taccari on tech-x11.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/external/mit/xorg/lib/freetype/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/mit/xorg/lib/freetype/Makefile
diff -u src/external/mit/xorg/lib/freetype/Makefile:1.12 src/external/mit/xorg/lib/freetype/Makefile:1.13
--- src/external/mit/xorg/lib/freetype/Makefile:1.12	Thu Mar 20 08:57:48 2014
+++ src/external/mit/xorg/lib/freetype/Makefile	Mon Jan 26 08:47:25 2015
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.12 2014/03/20 08:57:48 mrg Exp $
+#	$NetBSD: Makefile,v 1.13 2015/01/26 08:47:25 wiz Exp $
 
 .include bsd.own.mk
 
@@ -100,7 +100,7 @@ LIBDPLIBS= \
 
 PKGCONFIG=	freetype2
 PKGDIST.freetype2=	${.CURDIR}
-PKGCONFIG_VERSION.freetype2=	9.20.3
+PKGCONFIG_VERSION.freetype2=	17.2.11
 
 .include bsd.x11.mk
 .include bsd.lib.mk



CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 10:53:21 UTC 2015

Modified Files:
src/sys/dev/usb: usbdevs.h usbdevs_data.h

Log Message:
regen


To generate a diff of this commit:
cvs rdiff -u -r1.679 -r1.680 src/sys/dev/usb/usbdevs.h
cvs rdiff -u -r1.680 -r1.681 src/sys/dev/usb/usbdevs_data.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usbdevs.h
diff -u src/sys/dev/usb/usbdevs.h:1.679 src/sys/dev/usb/usbdevs.h:1.680
--- src/sys/dev/usb/usbdevs.h:1.679	Wed Dec 17 10:02:46 2014
+++ src/sys/dev/usb/usbdevs.h	Mon Jan 26 10:53:21 2015
@@ -1,10 +1,10 @@
-/*	$NetBSD: usbdevs.h,v 1.679 2014/12/17 10:02:46 jnemeth Exp $	*/
+/*	$NetBSD: usbdevs.h,v 1.680 2015/01/26 10:53:21 gson Exp $	*/
 
 /*
  * THIS FILE AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: usbdevs,v 1.687 2014/12/17 10:02:01 jnemeth Exp
+ *	NetBSD: usbdevs,v 1.688 2015/01/26 09:58:10 gson Exp
  */
 
 /*
@@ -2918,6 +2918,7 @@
 #define	USB_PRODUCT_SILABS2_DCU11CLONE	0xaa26		/* DCU-11 clone */
 #define	USB_PRODUCT_SILABS_CP210X_1	0xea60		/* CP210x Serial */
 #define	USB_PRODUCT_SILABS_CP210X_2	0xea61		/* CP210x Serial */
+#define	USB_PRODUCT_SILABS_EC3	0x8044		/* EC3 USB Debug Adapter */
 
 /* Silicon Portals Inc. */
 #define	USB_PRODUCT_SILICONPORTALS_YAPPH_NF	0x0200		/* YAP Phone (no firmware) */

Index: src/sys/dev/usb/usbdevs_data.h
diff -u src/sys/dev/usb/usbdevs_data.h:1.680 src/sys/dev/usb/usbdevs_data.h:1.681
--- src/sys/dev/usb/usbdevs_data.h:1.680	Wed Dec 17 10:02:46 2014
+++ src/sys/dev/usb/usbdevs_data.h	Mon Jan 26 10:53:21 2015
@@ -1,10 +1,10 @@
-/*	$NetBSD: usbdevs_data.h,v 1.680 2014/12/17 10:02:46 jnemeth Exp $	*/
+/*	$NetBSD: usbdevs_data.h,v 1.681 2015/01/26 10:53:21 gson Exp $	*/
 
 /*
  * THIS FILE AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: usbdevs,v 1.687 2014/12/17 10:02:01 jnemeth Exp
+ *	NetBSD: usbdevs,v 1.688 2015/01/26 09:58:10 gson Exp
  */
 
 /*
@@ -3956,60 +3956,62 @@ static const uint16_t usb_products[] = {
 	16977, 6548, 0,
 	USB_VENDOR_SILABS, USB_PRODUCT_SILABS_CP210X_2, 
 	16977, 6548, 0,
+	USB_VENDOR_SILABS, USB_PRODUCT_SILABS_EC3, 
+	16984, 4656, 16988, 4670, 0,
 	USB_VENDOR_SILICONPORTALS, USB_PRODUCT_SILICONPORTALS_YAPPH_NF, 
-	16984, 14045, 7218, 7222, 0,
+	16994, 14045, 7218, 7222, 0,
 	USB_VENDOR_SILICONPORTALS, USB_PRODUCT_SILICONPORTALS_YAPPHONE, 
-	16984, 14045, 0,
+	16994, 14045, 0,
 	USB_VENDOR_SIS, USB_PRODUCT_SIS_SIS_163U, 
-	16988, 3658, 6963, 4670, 0,
+	16998, 3658, 6963, 4670, 0,
 	USB_VENDOR_SIRIUS, USB_PRODUCT_SIRIUS_ROADSTER, 
-	16996, 17004, 6993, 17013, 4656, 0,
+	17006, 17014, 6993, 17023, 4656, 0,
 	USB_VENDOR_SITECOM, USB_PRODUCT_SITECOM_LN029, 
-	17016, 0,
+	17026, 0,
 	USB_VENDOR_SITECOM, USB_PRODUCT_SITECOM_CN104, 
-	17022, 9021, 0,
+	17032, 9021, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL168V1, 
-	17028, 17035, 0,
+	17038, 17045, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT2870_1, 
 	4882, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL168V4, 
-	17028, 17038, 0,
+	17038, 17048, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT2870_2, 
 	4882, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT2870_3, 
 	4882, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL302, 
-	17041, 0,
+	17051, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL603, 
-	17048, 0,
+	17058, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL315, 
-	17055, 0,
+	17065, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL321, 
-	17062, 0,
+	17072, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT3070_3, 
 	4889, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL324, 
-	17069, 0,
+	17079, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL343, 
-	17076, 0,
+	17086, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL608, 
-	17083, 0,
+	17093, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL344, 
-	17090, 0,
+	17100, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL329, 
-	17097, 0,
+	17107, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL345, 
-	17104, 0,
+	17114, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL353, 
-	17111, 0,
+	17121, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT3072_3, 
 	4903, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT3072_4, 
 	4903, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL349V1, 
-	17118, 17035, 0,
+	17128, 17045, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_WL349V4, 
-	17118, 17038, 0,
+	17128, 17048, 0,
 	USB_VENDOR_SITECOMEU, USB_PRODUCT_SITECOMEU_RT3070_1, 
 	4889, 0,
 	USB_VENDOR_SITECOMEU, 

CVS commit: [netbsd-5-2] src

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 11:02:37 UTC 2015

Modified Files:
src/crypto/dist/openssl/apps [netbsd-5-2]: s_client.c s_server.c
speed.c
src/crypto/dist/openssl/crypto [netbsd-5-2]: Makefile
constant_time_locl.h cversion.c
src/crypto/dist/openssl/crypto/asn1 [netbsd-5-2]: a_bitstr.c a_type.c
a_verify.c asn1.h asn1_err.c tasn_dec.c x_algor.c
src/crypto/dist/openssl/crypto/bio [netbsd-5-2]: bio.h bss_dgram.c
src/crypto/dist/openssl/crypto/bn [netbsd-5-2]: bn_asm.c bntest.c
src/crypto/dist/openssl/crypto/bn/asm [netbsd-5-2]: mips3.s
x86_64-gcc.c
src/crypto/dist/openssl/crypto/dsa [netbsd-5-2]: dsa_vrf.c
src/crypto/dist/openssl/crypto/ec [netbsd-5-2]: ec_mult.c ec_pmeth.c
src/crypto/dist/openssl/crypto/ecdsa [netbsd-5-2]: ecs_vrf.c
src/crypto/dist/openssl/crypto/evp [netbsd-5-2]: Makefile evp_enc.c
src/crypto/dist/openssl/crypto/objects [netbsd-5-2]: obj_xref.h
objxref.pl
src/crypto/dist/openssl/crypto/ts [netbsd-5-2]: ts_rsp_sign.c
src/crypto/dist/openssl/crypto/x509 [netbsd-5-2]: x509.h x509_vpm.c
x_all.c
src/crypto/dist/openssl/ssl [netbsd-5-2]: d1_both.c d1_clnt.c d1_enc.c
d1_lib.c d1_pkt.c d1_srvr.c dtls1.h s23_srvr.c s2_enc.c s2_pkt.c
s2_srvr.c s3_both.c s3_clnt.c s3_enc.c s3_lib.c s3_pkt.c s3_srvr.c
ssl.h ssl_cert.c ssl_lib.c ssl_locl.h
src/crypto/dist/openssl/util [netbsd-5-2]: libeay.num mk1mf.pl
src/distrib/sets/lists/base [netbsd-5-2]: md.amd64 md.sparc64 shl.mi
src/lib/libcrypto [netbsd-5-2]: shlib_version
src/lib/libssl [netbsd-5-2]: shlib_version

Log Message:
Change the following, requested by spz in ticket #1945:
crypto/dist/openssl/apps/s_client.c  patch
crypto/dist/openssl/apps/s_server.c  patch
crypto/dist/openssl/apps/speed.c patch
crypto/dist/openssl/crypto/Makefile  patch
crypto/dist/openssl/crypto/constant_time_locl.h  patch
crypto/dist/openssl/crypto/cversion.cpatch
crypto/dist/openssl/crypto/asn1/a_bitstr.c   patch
crypto/dist/openssl/crypto/asn1/a_type.c patch
crypto/dist/openssl/crypto/asn1/a_verify.c   patch
crypto/dist/openssl/crypto/asn1/asn1.h   patch
crypto/dist/openssl/crypto/asn1/asn1_err.c   patch
crypto/dist/openssl/crypto/asn1/tasn_dec.c   patch
crypto/dist/openssl/crypto/asn1/x_algor.cpatch
crypto/dist/openssl/crypto/bio/bio.h patch
crypto/dist/openssl/crypto/bio/bss_dgram.c   patch
crypto/dist/openssl/crypto/bn/bn_asm.c   patch
crypto/dist/openssl/crypto/bn/bntest.c   patch
crypto/dist/openssl/crypto/bn/asm/mips3.spatch
crypto/dist/openssl/crypto/bn/asm/x86_64-gcc.c   patch
crypto/dist/openssl/crypto/dsa/dsa_vrf.c patch
crypto/dist/openssl/crypto/ec/ec_mult.c  patch
crypto/dist/openssl/crypto/ec/ec_pmeth.c patch
crypto/dist/openssl/crypto/ecdsa/ecs_vrf.c   patch
crypto/dist/openssl/crypto/evp/Makefile  patch
crypto/dist/openssl/crypto/evp/evp_enc.c patch
crypto/dist/openssl/crypto/objects/obj_xref.hpatch
crypto/dist/openssl/crypto/objects/objxref.plpatch
crypto/dist/openssl/crypto/ts/ts_rsp_sign.c  patch
crypto/dist/openssl/crypto/x509/x509.h   patch
crypto/dist/openssl/crypto/x509/x509_vpm.c   patch
crypto/dist/openssl/crypto/x509/x_all.c  patch
crypto/dist/openssl/ssl/d1_both.cpatch
crypto/dist/openssl/ssl/d1_clnt.cpatch
crypto/dist/openssl/ssl/d1_enc.c patch
crypto/dist/openssl/ssl/d1_lib.c patch
crypto/dist/openssl/ssl/d1_pkt.c patch
crypto/dist/openssl/ssl/d1_srvr.cpatch
crypto/dist/openssl/ssl/dtls1.h  patch
crypto/dist/openssl/ssl/s23_srvr.c   patch
crypto/dist/openssl/ssl/s2_enc.c patch
crypto/dist/openssl/ssl/s2_pkt.c patch
crypto/dist/openssl/ssl/s2_srvr.cpatch
 

CVS commit: [netbsd-5-2] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 11:03:46 UTC 2015

Modified Files:
src/doc [netbsd-5-2]: CHANGES-5.2.4

Log Message:
Ticket #1945


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.12 -r1.1.2.13 src/doc/CHANGES-5.2.4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-5.2.4
diff -u src/doc/CHANGES-5.2.4:1.1.2.12 src/doc/CHANGES-5.2.4:1.1.2.13
--- src/doc/CHANGES-5.2.4:1.1.2.12	Wed Jan  7 18:43:39 2015
+++ src/doc/CHANGES-5.2.4	Mon Jan 26 11:03:46 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-5.2.4,v 1.1.2.12 2015/01/07 18:43:39 msaitoh Exp $
+# $NetBSD: CHANGES-5.2.4,v 1.1.2.13 2015/01/26 11:03:46 martin Exp $
 
 A complete list of changes from the NetBSD 5.2.3 release to the NetBSD 5.2.4
 release:
@@ -2449,3 +2449,77 @@ etc/rc.d/ntpd	1.15
 	New ntpd wants to be able to translate ntp into a port number after
 	chroot, so give it its own small copy of /etc/services in the chroot
 	[he, ticket #1940]
+
+crypto/dist/openssl/apps/s_client.c   patch
+crypto/dist/openssl/apps/s_server.c   patch
+crypto/dist/openssl/apps/speed.c  patch
+crypto/dist/openssl/crypto/Makefile   patch
+crypto/dist/openssl/crypto/constant_time_locl.h   patch
+crypto/dist/openssl/crypto/cversion.c patch
+crypto/dist/openssl/crypto/asn1/a_bitstr.cpatch
+crypto/dist/openssl/crypto/asn1/a_type.c  patch
+crypto/dist/openssl/crypto/asn1/a_verify.cpatch
+crypto/dist/openssl/crypto/asn1/asn1.hpatch
+crypto/dist/openssl/crypto/asn1/asn1_err.cpatch
+crypto/dist/openssl/crypto/asn1/tasn_dec.cpatch
+crypto/dist/openssl/crypto/asn1/x_algor.c patch
+crypto/dist/openssl/crypto/bio/bio.h  patch
+crypto/dist/openssl/crypto/bio/bss_dgram.cpatch
+crypto/dist/openssl/crypto/bn/bn_asm.cpatch
+crypto/dist/openssl/crypto/bn/bntest.cpatch
+crypto/dist/openssl/crypto/bn/asm/mips3.s patch
+crypto/dist/openssl/crypto/bn/asm/x86_64-gcc.cpatch
+crypto/dist/openssl/crypto/dsa/dsa_vrf.c  patch
+crypto/dist/openssl/crypto/ec/ec_mult.c   patch
+crypto/dist/openssl/crypto/ec/ec_pmeth.c  patch
+crypto/dist/openssl/crypto/ecdsa/ecs_vrf.cpatch
+crypto/dist/openssl/crypto/evp/Makefile   patch
+crypto/dist/openssl/crypto/evp/evp_enc.c  patch
+crypto/dist/openssl/crypto/objects/obj_xref.h patch
+crypto/dist/openssl/crypto/objects/objxref.pl patch
+crypto/dist/openssl/crypto/ts/ts_rsp_sign.c   patch
+crypto/dist/openssl/crypto/x509/x509.hpatch
+crypto/dist/openssl/crypto/x509/x509_vpm.cpatch
+crypto/dist/openssl/crypto/x509/x_all.c   patch
+crypto/dist/openssl/ssl/d1_both.c patch
+crypto/dist/openssl/ssl/d1_clnt.c patch
+crypto/dist/openssl/ssl/d1_enc.c  patch
+crypto/dist/openssl/ssl/d1_lib.c  patch
+crypto/dist/openssl/ssl/d1_pkt.c  patch
+crypto/dist/openssl/ssl/d1_srvr.c patch
+crypto/dist/openssl/ssl/dtls1.h   patch
+crypto/dist/openssl/ssl/s23_srvr.cpatch
+crypto/dist/openssl/ssl/s2_enc.c  patch
+crypto/dist/openssl/ssl/s2_pkt.c  patch
+crypto/dist/openssl/ssl/s2_srvr.c patch
+crypto/dist/openssl/ssl/s3_both.c patch
+crypto/dist/openssl/ssl/s3_clnt.c patch
+crypto/dist/openssl/ssl/s3_enc.c  patch
+crypto/dist/openssl/ssl/s3_lib.c  patch
+crypto/dist/openssl/ssl/s3_pkt.c  patch
+crypto/dist/openssl/ssl/s3_srvr.c patch
+crypto/dist/openssl/ssl/ssl.h patch
+crypto/dist/openssl/ssl/ssl_cert.cpatch
+crypto/dist/openssl/ssl/ssl_lib.c patch
+crypto/dist/openssl/ssl/ssl_locl.hpatch
+crypto/dist/openssl/util/libeay.num   patch
+crypto/dist/openssl/util/mk1mf.pl 

CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 11:05:21 UTC 2015

Modified Files:
src/sys/dev/usb: usb_quirks.c

Log Message:
The Silicon Labs EC3 USB Debug Adapter looks like a HID, but needs to
be accessed via the ugen driver.


To generate a diff of this commit:
cvs rdiff -u -r1.81 -r1.82 src/sys/dev/usb/usb_quirks.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/usb_quirks.c
diff -u src/sys/dev/usb/usb_quirks.c:1.81 src/sys/dev/usb/usb_quirks.c:1.82
--- src/sys/dev/usb/usb_quirks.c:1.81	Fri Sep 12 16:40:38 2014
+++ src/sys/dev/usb/usb_quirks.c	Mon Jan 26 11:05:20 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: usb_quirks.c,v 1.81 2014/09/12 16:40:38 skrll Exp $	*/
+/*	$NetBSD: usb_quirks.c,v 1.82 2015/01/26 11:05:20 gson Exp $	*/
 /*	$FreeBSD: src/sys/dev/usb/usb_quirks.c,v 1.30 2003/01/02 04:15:55 imp Exp $	*/
 
 /*
@@ -32,7 +32,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: usb_quirks.c,v 1.81 2014/09/12 16:40:38 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: usb_quirks.c,v 1.82 2015/01/26 11:05:20 gson Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_usb.h
@@ -67,6 +67,7 @@ Static const struct usbd_quirk_entry {
  { USB_VENDOR_TRIPPLITE2, ANY,			ANY,   { UQ_HID_IGNORE }},
  { USB_VENDOR_MISC, USB_PRODUCT_MISC_WISPY_24X, ANY, { UQ_HID_IGNORE }},
  { USB_VENDOR_WELTREND, USB_PRODUCT_WELTREND_HID,   ANY,   { UQ_HID_IGNORE }},
+ { USB_VENDOR_SILABS, USB_PRODUCT_SILABS_EC3,   ANY,   { UQ_HID_IGNORE }},
 
  { USB_VENDOR_KYE, USB_PRODUCT_KYE_NICHE,	0x100, { UQ_NO_SET_PROTO}},
  { USB_VENDOR_INSIDEOUT, USB_PRODUCT_INSIDEOUT_EDGEPORT4,



CVS commit: [netbsd-5-1] src

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 11:47:24 UTC 2015

Modified Files:
src/crypto/dist/openssl/apps [netbsd-5-1]: s_client.c s_server.c
speed.c
src/crypto/dist/openssl/crypto [netbsd-5-1]: Makefile
constant_time_locl.h cversion.c
src/crypto/dist/openssl/crypto/asn1 [netbsd-5-1]: a_bitstr.c a_type.c
a_verify.c asn1.h asn1_err.c tasn_dec.c x_algor.c
src/crypto/dist/openssl/crypto/bio [netbsd-5-1]: bio.h bss_dgram.c
src/crypto/dist/openssl/crypto/bn [netbsd-5-1]: bn_asm.c bntest.c
src/crypto/dist/openssl/crypto/bn/asm [netbsd-5-1]: mips3.s
x86_64-gcc.c
src/crypto/dist/openssl/crypto/dsa [netbsd-5-1]: dsa_vrf.c
src/crypto/dist/openssl/crypto/ec [netbsd-5-1]: ec_mult.c ec_pmeth.c
src/crypto/dist/openssl/crypto/ecdsa [netbsd-5-1]: ecs_vrf.c
src/crypto/dist/openssl/crypto/evp [netbsd-5-1]: Makefile evp_enc.c
src/crypto/dist/openssl/crypto/objects [netbsd-5-1]: obj_xref.h
objxref.pl
src/crypto/dist/openssl/crypto/ts [netbsd-5-1]: ts_rsp_sign.c
src/crypto/dist/openssl/crypto/x509 [netbsd-5-1]: x509.h x509_vpm.c
x_all.c
src/crypto/dist/openssl/ssl [netbsd-5-1]: d1_both.c d1_clnt.c d1_enc.c
d1_lib.c d1_pkt.c d1_srvr.c dtls1.h s23_srvr.c s2_enc.c s2_pkt.c
s2_srvr.c s3_both.c s3_clnt.c s3_enc.c s3_lib.c s3_pkt.c s3_srvr.c
ssl.h ssl_cert.c ssl_lib.c ssl_locl.h
src/crypto/dist/openssl/util [netbsd-5-1]: libeay.num mk1mf.pl
src/distrib/sets/lists/base [netbsd-5-1]: md.amd64 md.sparc64 shl.mi
src/lib/libcrypto [netbsd-5-1]: shlib_version
src/lib/libssl [netbsd-5-1]: shlib_version

Log Message:
Change the following, requested by spz in ticket #1945:
crypto/dist/openssl/apps/s_client.c  patch
crypto/dist/openssl/apps/s_server.c  patch
crypto/dist/openssl/apps/speed.c patch
crypto/dist/openssl/crypto/Makefile  patch
crypto/dist/openssl/crypto/constant_time_locl.h  patch
crypto/dist/openssl/crypto/cversion.cpatch
crypto/dist/openssl/crypto/asn1/a_bitstr.c   patch
crypto/dist/openssl/crypto/asn1/a_type.c patch
crypto/dist/openssl/crypto/asn1/a_verify.c   patch
crypto/dist/openssl/crypto/asn1/asn1.h   patch
crypto/dist/openssl/crypto/asn1/asn1_err.c   patch
crypto/dist/openssl/crypto/asn1/tasn_dec.c   patch
crypto/dist/openssl/crypto/asn1/x_algor.cpatch
crypto/dist/openssl/crypto/bio/bio.h patch
crypto/dist/openssl/crypto/bio/bss_dgram.c   patch
crypto/dist/openssl/crypto/bn/bn_asm.c   patch
crypto/dist/openssl/crypto/bn/bntest.c   patch
crypto/dist/openssl/crypto/bn/asm/mips3.spatch
crypto/dist/openssl/crypto/bn/asm/x86_64-gcc.c   patch
crypto/dist/openssl/crypto/dsa/dsa_vrf.c patch
crypto/dist/openssl/crypto/ec/ec_mult.c  patch
crypto/dist/openssl/crypto/ec/ec_pmeth.c patch
crypto/dist/openssl/crypto/ecdsa/ecs_vrf.c   patch
crypto/dist/openssl/crypto/evp/Makefile  patch
crypto/dist/openssl/crypto/evp/evp_enc.c patch
crypto/dist/openssl/crypto/objects/obj_xref.hpatch
crypto/dist/openssl/crypto/objects/objxref.plpatch
crypto/dist/openssl/crypto/ts/ts_rsp_sign.c  patch
crypto/dist/openssl/crypto/x509/x509.h   patch
crypto/dist/openssl/crypto/x509/x509_vpm.c   patch
crypto/dist/openssl/crypto/x509/x_all.c  patch
crypto/dist/openssl/ssl/d1_both.cpatch
crypto/dist/openssl/ssl/d1_clnt.cpatch
crypto/dist/openssl/ssl/d1_enc.c patch
crypto/dist/openssl/ssl/d1_lib.c patch
crypto/dist/openssl/ssl/d1_pkt.c patch
crypto/dist/openssl/ssl/d1_srvr.cpatch
crypto/dist/openssl/ssl/dtls1.h  patch
crypto/dist/openssl/ssl/s23_srvr.c   patch
crypto/dist/openssl/ssl/s2_enc.c patch
crypto/dist/openssl/ssl/s2_pkt.c patch
crypto/dist/openssl/ssl/s2_srvr.cpatch
 

CVS commit: [netbsd-5-1] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 11:51:16 UTC 2015

Modified Files:
src/doc [netbsd-5-1]: CHANGES-5.1.6

Log Message:
Ticket #1945


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.12 -r1.1.2.13 src/doc/CHANGES-5.1.6

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-5.1.6
diff -u src/doc/CHANGES-5.1.6:1.1.2.12 src/doc/CHANGES-5.1.6:1.1.2.13
--- src/doc/CHANGES-5.1.6:1.1.2.12	Wed Jan  7 18:44:13 2015
+++ src/doc/CHANGES-5.1.6	Mon Jan 26 11:51:16 2015
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-5.1.6,v 1.1.2.12 2015/01/07 18:44:13 msaitoh Exp $
+# $NetBSD: CHANGES-5.1.6,v 1.1.2.13 2015/01/26 11:51:16 martin Exp $
 
 A complete list of changes from the NetBSD 5.1.5 release to the NetBSD 5.1.6
 release:
@@ -2449,3 +2449,78 @@ etc/rc.d/ntpd	1.15
 	New ntpd wants to be able to translate ntp into a port number after
 	chroot, so give it its own small copy of /etc/services in the chroot
 	[he, ticket #1940]
+
+crypto/dist/openssl/apps/s_client.c   patch
+crypto/dist/openssl/apps/s_server.c   patch
+crypto/dist/openssl/apps/speed.c  patch
+crypto/dist/openssl/crypto/Makefile   patch
+crypto/dist/openssl/crypto/constant_time_locl.h   patch
+crypto/dist/openssl/crypto/cversion.c patch
+crypto/dist/openssl/crypto/asn1/a_bitstr.cpatch
+crypto/dist/openssl/crypto/asn1/a_type.c  patch
+crypto/dist/openssl/crypto/asn1/a_verify.cpatch
+crypto/dist/openssl/crypto/asn1/asn1.hpatch
+crypto/dist/openssl/crypto/asn1/asn1_err.cpatch
+crypto/dist/openssl/crypto/asn1/tasn_dec.cpatch
+crypto/dist/openssl/crypto/asn1/x_algor.c patch
+crypto/dist/openssl/crypto/bio/bio.h  patch
+crypto/dist/openssl/crypto/bio/bss_dgram.cpatch
+crypto/dist/openssl/crypto/bn/bn_asm.cpatch
+crypto/dist/openssl/crypto/bn/bntest.cpatch
+crypto/dist/openssl/crypto/bn/asm/mips3.s patch
+crypto/dist/openssl/crypto/bn/asm/x86_64-gcc.cpatch
+crypto/dist/openssl/crypto/dsa/dsa_vrf.c  patch
+crypto/dist/openssl/crypto/ec/ec_mult.c   patch
+crypto/dist/openssl/crypto/ec/ec_pmeth.c  patch
+crypto/dist/openssl/crypto/ecdsa/ecs_vrf.cpatch
+crypto/dist/openssl/crypto/evp/Makefile   patch
+crypto/dist/openssl/crypto/evp/evp_enc.c  patch
+crypto/dist/openssl/crypto/objects/obj_xref.h patch
+crypto/dist/openssl/crypto/objects/objxref.pl patch
+crypto/dist/openssl/crypto/ts/ts_rsp_sign.c   patch
+crypto/dist/openssl/crypto/x509/x509.hpatch
+crypto/dist/openssl/crypto/x509/x509_vpm.cpatch
+crypto/dist/openssl/crypto/x509/x_all.c   patch
+crypto/dist/openssl/ssl/d1_both.c patch
+crypto/dist/openssl/ssl/d1_clnt.c patch
+crypto/dist/openssl/ssl/d1_enc.c  patch
+crypto/dist/openssl/ssl/d1_lib.c  patch
+crypto/dist/openssl/ssl/d1_pkt.c  patch
+crypto/dist/openssl/ssl/d1_srvr.c patch
+crypto/dist/openssl/ssl/dtls1.h   patch
+crypto/dist/openssl/ssl/s23_srvr.cpatch
+crypto/dist/openssl/ssl/s2_enc.c  patch
+crypto/dist/openssl/ssl/s2_pkt.c  patch
+crypto/dist/openssl/ssl/s2_srvr.c patch
+crypto/dist/openssl/ssl/s3_both.c patch
+crypto/dist/openssl/ssl/s3_clnt.c patch
+crypto/dist/openssl/ssl/s3_enc.c  patch
+crypto/dist/openssl/ssl/s3_lib.c  patch
+crypto/dist/openssl/ssl/s3_pkt.c  patch
+crypto/dist/openssl/ssl/s3_srvr.c patch
+crypto/dist/openssl/ssl/ssl.h patch
+crypto/dist/openssl/ssl/ssl_cert.cpatch
+crypto/dist/openssl/ssl/ssl_lib.c patch
+crypto/dist/openssl/ssl/ssl_locl.hpatch
+crypto/dist/openssl/util/libeay.num   patch
+crypto/dist/openssl/util/mk1mf.pl 

CVS commit: src/share/man/man4

2015-01-26 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Mon Jan 26 22:47:41 UTC 2015

Modified Files:
src/share/man/man4: uaudio.4

Log Message:
Remove trailing whitespace.


To generate a diff of this commit:
cvs rdiff -u -r1.28 -r1.29 src/share/man/man4/uaudio.4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man4/uaudio.4
diff -u src/share/man/man4/uaudio.4:1.28 src/share/man/man4/uaudio.4:1.29
--- src/share/man/man4/uaudio.4:1.28	Mon Jan 26 20:53:49 2015
+++ src/share/man/man4/uaudio.4	Mon Jan 26 22:47:41 2015
@@ -1,4 +1,4 @@
-.\ $NetBSD: uaudio.4,v 1.28 2015/01/26 20:53:49 gson Exp $
+.\ $NetBSD: uaudio.4,v 1.29 2015/01/26 22:47:41 wiz Exp $
 .\
 .\ Copyright (c) 1999 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -120,7 +120,7 @@ driver
 appeared in
 .Nx 1.5 .
 .Sh BUGS
-Releases 1.0 and 2.0 of the 
+Releases 1.0 and 2.0 of the
 .Tn USB
 Audio class specification are not mutually compatible.
 The



CVS commit: src/share/man/man4

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 20:53:12 UTC 2015

Modified Files:
src/share/man/man4: uaudio.4

Log Message:
Note that revision 2.0 of the audio device class spec is not supported.


To generate a diff of this commit:
cvs rdiff -u -r1.26 -r1.27 src/share/man/man4/uaudio.4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man4/uaudio.4
diff -u src/share/man/man4/uaudio.4:1.26 src/share/man/man4/uaudio.4:1.27
--- src/share/man/man4/uaudio.4:1.26	Mon Jan 26 20:41:49 2015
+++ src/share/man/man4/uaudio.4	Mon Jan 26 20:53:12 2015
@@ -1,4 +1,4 @@
-.\ $NetBSD: uaudio.4,v 1.26 2015/01/26 20:41:49 gson Exp $
+.\ $NetBSD: uaudio.4,v 1.27 2015/01/26 20:53:12 gson Exp $
 .\
 .\ Copyright (c) 1999 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -120,6 +120,13 @@ driver
 appeared in
 .Nx 1.5 .
 .Sh BUGS
+Releases 1.0 and 2.0 of the 
+.Tn USB
+Audio class specification are not mutually compatible.
+The
+.Nm
+driver only supports devices compliant with Release 1.0.
+.Pp
 There is no support for multiple-endpoints audio stream,
 adaptive recording, async playback, and TYPE-II/III formats.
 .Pp



CVS commit: src/share/man/man4

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 20:53:49 UTC 2015

Modified Files:
src/share/man/man4: uaudio.4

Log Message:
bump date


To generate a diff of this commit:
cvs rdiff -u -r1.27 -r1.28 src/share/man/man4/uaudio.4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man4/uaudio.4
diff -u src/share/man/man4/uaudio.4:1.27 src/share/man/man4/uaudio.4:1.28
--- src/share/man/man4/uaudio.4:1.27	Mon Jan 26 20:53:12 2015
+++ src/share/man/man4/uaudio.4	Mon Jan 26 20:53:49 2015
@@ -1,4 +1,4 @@
-.\ $NetBSD: uaudio.4,v 1.27 2015/01/26 20:53:12 gson Exp $
+.\ $NetBSD: uaudio.4,v 1.28 2015/01/26 20:53:49 gson Exp $
 .\
 .\ Copyright (c) 1999 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -27,7 +27,7 @@
 .\ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 .\ POSSIBILITY OF SUCH DAMAGE.
 .\
-.Dd September 20, 2011
+.Dd January 26, 2015
 .Dt UAUDIO 4
 .Os
 .Sh NAME



CVS commit: src/sys/dev/usb

2015-01-26 Thread Andreas Gustafsson
Module Name:src
Committed By:   gson
Date:   Mon Jan 26 20:56:44 UTC 2015

Modified Files:
src/sys/dev/usb: uaudio.c

Log Message:
Fix URLs of USB audio specs


To generate a diff of this commit:
cvs rdiff -u -r1.143 -r1.144 src/sys/dev/usb/uaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/uaudio.c
diff -u src/sys/dev/usb/uaudio.c:1.143 src/sys/dev/usb/uaudio.c:1.144
--- src/sys/dev/usb/uaudio.c:1.143	Mon Jan 26 20:37:44 2015
+++ src/sys/dev/usb/uaudio.c	Mon Jan 26 20:56:44 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: uaudio.c,v 1.143 2015/01/26 20:37:44 gson Exp $	*/
+/*	$NetBSD: uaudio.c,v 1.144 2015/01/26 20:56:44 gson Exp $	*/
 
 /*
  * Copyright (c) 1999, 2012 The NetBSD Foundation, Inc.
@@ -31,13 +31,13 @@
  */
 
 /*
- * USB audio specs: http://www.usb.org/developers/devclass_docs/audio10.pdf
- *  http://www.usb.org/developers/devclass_docs/frmts10.pdf
- *  http://www.usb.org/developers/devclass_docs/termt10.pdf
+ * USB audio specs: http://www.usb.org/developers/docs/devclass_docs/audio10.pdf
+ *  http://www.usb.org/developers/docs/devclass_docs/frmts10.pdf
+ *  http://www.usb.org/developers/docs/devclass_docs/termt10.pdf
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.143 2015/01/26 20:37:44 gson Exp $);
+__KERNEL_RCSID(0, $NetBSD: uaudio.c,v 1.144 2015/01/26 20:56:44 gson Exp $);
 
 #ifdef _KERNEL_OPT
 #include opt_usb.h
Index: src/sys/arch/x86/include/specialreg.h
diff -u src/sys/arch/x86/include/specialreg.h:1.55.2.4 src/sys/arch/x86/include/specialreg.h:1.55.2.5
--- src/sys/arch/x86/include/specialreg.h:1.55.2.4	Mon Dec 29 15:31:06 2014
+++ src/sys/arch/x86/include/specialreg.h	Mon Jan 26 13:58:05 2015
@@ -1,4 +1,4 @@
-/*	$NetBSD: specialreg.h,v 1.55.2.4 2014/12/29 15:31:06 martin Exp $	*/
+/*	$NetBSD: specialreg.h,v 1.55.2.5 2015/01/26 13:58:05 martin Exp $	*/
 
 /*-
  * Copyright (c) 1991 The Regents of the University of California.
@@ -221,19 +221,39 @@
 	\31 DEADLINE \32 AES	\33 XSAVE	\34 OSXSAVE \
 	\35 AVX	\36 F16C	\37 RDRAND	\40 RAZ
 
-#define CPUID2FAMILY(cpuid)	(((cpuid)  8)  0xf)
-#define CPUID2MODEL(cpuid)	(((cpuid)  4)  0xf)
-#define CPUID2STEPPING(cpuid)	((cpuid)  0xf)
+/* CPUID Fn0001 %eax */
+
+#define CPUID_TO_BASEFAMILY(cpuid)	(((cpuid)  8)  0xf)
+#define CPUID_TO_BASEMODEL(cpuid)	(((cpuid)  4)  0xf)
+#define CPUID_TO_STEPPING(cpuid)	((cpuid)  0xf)
+
+/* Old macros for compatibility */
+#define CPUID2FAMILY(cpuid)	CPUID_TO_BASEFAMILY(cpuid)
+#define CPUID2MODEL(cpuid)	CPUID_TO_BASEMODEL(cpuid)
+#define CPUID2STEPPING(cpuid)	CPUID_TO_STEPPING(cpuid)
 
 /*
  * The Extended family bits should only be inspected when CPUID2FAMILY()
  * returns 15. They are use to encode family value 16 to 270 (add 15).
- * The Extended model hits are the high 4 bits of the model.
+ * The Extended model bits are the high 4 bits of the model.
  * They are only valid for family = 15 or family 6 (intel, but all amd
  * family 6 are documented to return zero bits for them).
  */
-#define CPUID2EXTFAMILY(cpuid)	(((cpuid)  20)  0xff)
-#define CPUID2EXTMODEL(cpuid)	(((cpuid)  16)  0xf)
+#define CPUID_TO_EXTFAMILY(cpuid)	(((cpuid)  20)  0xff)
+#define CPUID_TO_EXTMODEL(cpuid)	(((cpuid)  16)  0xf)
+
+/* Old macros for compatibility */
+#define CPUID2EXTFAMILY(cpuid)	CPUID_TO_EXTFAMILY(cpuid)
+#define CPUID2EXTMODEL(cpuid)	CPUID_TO_EXTMODEL(cpuid)
+
+/* The macros for the Display Family and the Display Model */
+#define CPUID_TO_FAMILY(cpuid)	(CPUID_TO_BASEFAMILY(cpuid)	\
+	+ ((CPUID_TO_BASEFAMILY(cpuid) != 0x0f)		\
+		? 0 : CPUID_TO_EXTFAMILY(cpuid)))
+#define CPUID_TO_MODEL(cpuid)	(CPUID_TO_BASEMODEL(cpuid)	\
+	| ((CPUID_TO_BASEFAMILY(cpuid) != 0x0f)		\
+		 (CPUID_TO_BASEFAMILY(cpuid) != 0x06)		\
+		? 0 : (CPUID_TO_EXTMODEL(cpuid)  4)))
 
 /*
  * Intel Deterministic Cache Parameter Leaf
@@ -221,19 +221,39 @@
 
 /*
- * The Extended family bits should only be inspected when CPUID2FAMILY()
+ * The Extended family bits should only be inspected when CPUID_TO_BASEFAMILY()
  * returns 15. They are use to encode family value 16 to 270 (add 15).



CVS commit: [netbsd-6] src/doc

2015-01-26 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Jan 26 14:04:22 UTC 2015

Modified Files:
src/doc [netbsd-6]: CHANGES-6.2

Log Message:
Tickets #1240 and #1241


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.189 -r1.1.2.190 src/doc/CHANGES-6.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
